package bare_encoding

  1. Overview
  2. Docs

Module type Bare_encoding.INPUTSource

Input type.

An input is a source of bytes, used to decode.

Sourceval read_byte : unit -> char

Read a single byte.

Sourceval read_i16 : unit -> int

Read 2 bytes, in little endian.

Sourceval read_i32 : unit -> int32

Read 4 bytes, in little endian.

Sourceval read_i64 : unit -> int64

Read 8 bytes, in little endian.

Sourceval read_exact : bytes -> int -> int -> unit

read_exact buf i len reads len bytes into buf, starting at offset i